@@ -4,7 +4,7 @@ use Lemonldap::NG::Handler::Simple qw(:locationRules :headers);
 use strict;
 use MIME::Base64;
 
-our $VERSION = '0.52';
+our $VERSION = '0.53';
 
 # TODO: split locationRules into 2 arrays
 sub locationRulesInit {
@@ -29,6 +29,7 @@ sub locationRulesInit {
         $defaultCondition->{$vhost} = $class->conditionSub('accept')
           unless ( $defaultCondition->{$vhost} );
     }
+    1;
 }
 
 sub forgeHeadersInit {
@@ -56,6 +57,7 @@ sub forgeHeadersInit {
             'error' )
           if ($@);
     }
+    1;
 }
 
 sub sendHeaders {
@@ -85,7 +87,7 @@ sub grant {
         );
         return 0;
     }
-    return &{ $defaultCondition->{$vhost} };
+    return &{ $defaultCondition->{$vhost} }($datas);
 }
 
 1;
@@ -112,9 +114,9 @@ Create your own package:
                  'default' => '$ou =~ /brh/'
              },
              'vhost2.dc.com' => {
-                 '^/pj/.*$'       => q($qualif="opj"),
-                 '^/rh/.*$'       => q($ou=~/brh/),
-                 '^/rh_or_opj.*$' => q($qualif="opj or $ou=~/brh/),
+                 '^/pj/.*$'       => '$qualif="opj"',
+                 '^/rh/.*$'       => '$ou=~/brh/',
+                 '^/rh_or_opj.*$' => '$qualif="opj" or $ou=~/brh/',
                  default          => 'accept',
              },
              # Put here others Lemonldap::NG::Handler::Simple options
